#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-12-30
# File  : fritzbox_smarthome_power_socket.py (check plugin)
#
#

from typing import Dict

from cmk.base.plugins.agent_based.agent_based_api.v1 import (
    Service,
    register,
    Result,
    State,
)
from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import CheckResult, DiscoveryResult
from cmk.base.plugins.agent_based.utils.fritzbox_smarthome import AvmSmartHomeDevice


def discovery_fritzbox_smarthome_power_socket_single(
        section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> DiscoveryResult:
    if isinstance(section, AvmSmartHomeDevice):
        if section.switch is not None:
            yield Service()


def discovery_fritzbox_smarthome_power_socket_multiple(
        section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> DiscoveryResult:
    if not isinstance(section, AvmSmartHomeDevice):
        for device_id, device in section.items():
            if device.switch is not None:
                yield Service(item=str(device_id))


def check_fritzbox_smarthome_power_socket_single(
        params, section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> CheckResult:
    if not isinstance(section, AvmSmartHomeDevice) or not section.switch:
        return

    def _get_status(status: int):
        _state = {
            0: ('off', params.get('state', {}).get('off', 0)),
            1: ('on', params.get('state', {}).get('on', 0)),
        }
        return _state.get(status, (f'unknown ({status})', 3))

    state_readable, state = _get_status(section.switch.state)
    yield Result(state=State(state), summary=f'State: {state_readable}')

    def _get_mode(mode: str):
        _mode = {
            'manuell': ('manuell', params.get('mode', {}).get('manuell', 0)),
            'automatic': ('automatic', params.get('mode', {}).get('automatic', 0)),
        }
        return _mode.get(mode, (f'unknown ({mode})', 3))

    mode_readable, mode = _get_mode(section.switch.mode)
    yield Result(state=State(mode), summary=f'Mode: {mode_readable}')


def check_fritzbox_smarthome_power_socket_multiple(
        item, params, section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> CheckResult:
    if isinstance(section, Dict):
        try:
            yield from check_fritzbox_smarthome_power_socket_single(params, section[item])
        except KeyError:
            return


register.check_plugin(
    name='fritzbox_smarthome_power_socket_single',
    service_name='Power socket',
    sections=['fritzbox_smarthome'],
    discovery_function=discovery_fritzbox_smarthome_power_socket_single,
    check_function=check_fritzbox_smarthome_power_socket_single,
    check_ruleset_name='fritzbox_smarthome_power_socket_single',
    check_default_parameters={}
)


register.check_plugin(
    name='fritzbox_smarthome_power_socket_multiple',
    service_name='Smarthome Power socket %s',
    sections=['fritzbox_smarthome'],
    discovery_function=discovery_fritzbox_smarthome_power_socket_multiple,
    check_function=check_fritzbox_smarthome_power_socket_multiple,
    check_ruleset_name='fritzbox_smarthome_power_socket_multiple',
    check_default_parameters={}
)
