#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-12-30
# File  : fritzbox_smarthome_power_socket.py (check plugin)
#
#

from typing import Dict

from cmk.base.plugins.agent_based.agent_based_api.v1 import (
    Service,
    register,
    Result,
    State,
)
from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import CheckResult, DiscoveryResult
from cmk.base.plugins.agent_based.utils.fritzbox_smarthome import AvmSmartHomeDevice


def discovery_fritzbox_smarthome_switch_single(
        section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> DiscoveryResult:
    if isinstance(section, AvmSmartHomeDevice):
        if section.simple_on_off is not None:
            yield Service()


def discovery_fritzbox_smarthome_switch_multiple(
        section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> DiscoveryResult:
    if not isinstance(section, AvmSmartHomeDevice):
        for device_id, device in section.items():
            if device.simple_on_off is not None:
                yield Service(item=str(device_id))


def check_fritzbox_smarthome_switch_single(
        params, section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> CheckResult:
    if not isinstance(section, AvmSmartHomeDevice) or section.simple_on_off is None:
        return

    def _get_status(status: int):
        _simple_onf_off_state = {
            0: 'off',
            1: 'on',
        }
        return _simple_onf_off_state.get(status, f'unknown ({status})')

    yield Result(state=State.OK, summary=f'State: {_get_status(section.switch.state)}')


def check_fritzbox_smarthome_switch_multiple(
        item, params, section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> CheckResult:
    if isinstance(section, Dict):
        try:
            yield from check_fritzbox_smarthome_switch_single(params, section[item])
        except KeyError:
            return


register.check_plugin(
    name='fritzbox_smarthome_switch_single',
    service_name='Switch',
    sections=['fritzbox_smarthome'],
    discovery_function=discovery_fritzbox_smarthome_switch_single,
    check_function=check_fritzbox_smarthome_switch_single,
    # check_ruleset_name='fritzbox_smarthome_switch',
    check_default_parameters={}
)


register.check_plugin(
    name='fritzbox_smarthome_switch_multiple',
    service_name='Smarthome Switch %s',
    sections=['fritzbox_smarthome'],
    discovery_function=discovery_fritzbox_smarthome_switch_multiple,
    check_function=check_fritzbox_smarthome_switch_multiple,
    # check_ruleset_name='fritzbox_smarthome_switch',
    check_default_parameters={}
)
