#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-12-28
# File  : fritzbox_smarthome_lock.py (WATO check plugin)
#


from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    MonitoringState,
    TextInput,
    Alternative,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)


def _parameter_valuespec_fritzbox_smarthome_lock(message: str):
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('lock',
             Alternative(
                 title=_(message),
                 elements=[
                     Dictionary(
                         title=_('Activated'),
                         optional_keys=False,
                         elements=[
                             ('activated',
                              MonitoringState(
                                  title=_('Monitoring state'),
                                  default_value=0,
                              )),
                         ]),
                     Dictionary(
                         title=_('Deactivated'),
                         optional_keys=False,
                         elements=[
                             ('deactivated',
                              MonitoringState(
                                  title=_('Monitoring state'),
                                  default_value=0,
                              ))
                         ]),
                 ]
             )),
        ],
    )


def _parameter_valuespec_fritzbox_smarthome_app_lock():
    return _parameter_valuespec_fritzbox_smarthome_lock(message='Manual access for phone, app or user interface')


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_app_lock_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_app_lock,
        title=lambda: _('Fritz!Box Smarthome App Lock')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_app_lock_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_app_lock,
        title=lambda: _('Fritz!Box Smarthome App Look (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)


def _parameter_valuespec_fritzbox_smarthome_device_lock():
    return _parameter_valuespec_fritzbox_smarthome_lock(message='Button lock on the device')


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_device_lock_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_device_lock,
        title=lambda: _('Fritz!Box Smarthome Device Lock')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_device_lock_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_device_lock,
        title=lambda: _('Fritz!Box Smarthome Device Lock (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)
