#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-01-09
# File  : fritzbox_smarthome_lock.py (WATO check plugin)
#


from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    MonitoringState,
    TextInput,
    Alternative,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)


def _parameter_valuespec_fritzbox_smarthome_power_socket():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('state',
             Alternative(
                 title=_('Power Socket state'),
                 elements=[
                     Dictionary(
                         title=_('Switched On'),
                         optional_keys=False,
                         elements=[
                             ('on',
                              MonitoringState(
                                  title=_('Monitoring state'),
                                  default_value=0,
                              )),
                         ]),
                     Dictionary(
                         title=_('Switched off'),
                         optional_keys=False,
                         elements=[
                             ('off',
                              MonitoringState(
                                  title=_('Monitoring state'),
                                  default_value=0,
                              ))
                         ]),
                 ]
             )),
            ('mode',
             Alternative(
                 title=_('Power Socket switching mode'),
                 elements=[
                     Dictionary(
                         title=_('Manuell'),
                         optional_keys=False,
                         elements=[
                             ('manuell',
                              MonitoringState(
                                  title=_('Monitoring state'),
                                  default_value=0,
                              )),
                         ]),
                     Dictionary(
                         title=_('Automatic'),
                         optional_keys=False,
                         elements=[
                             ('automatic',
                              MonitoringState(
                                  title=_('Monitoring state'),
                                  default_value=0,
                              ))
                         ]),
                 ]
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_power_socket_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_power_socket,
        title=lambda: _('Fritz!Box Smarthome Power socket')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_power_socket_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_power_socket,
        title=lambda: _('Fritz!Box Smarthome Power Socket (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)
